@@ -3,7 +3,7 @@ required <- c("MASS")
 if (!all(sapply(required, requireNamespace, quietly = TRUE)))
   knitr::opts_chunk$set(eval = FALSE)
 knitr::opts_chunk$set(message = F, warning = F, fig.width = 6, fig.height = 5,
-                      render = knitr::normal_print)
+                      dpi = 150, render = knitr::normal_print)
 library(jtools)
 
 ## -----------------------------------------------------------------------------
